@@ -2,7 +2,6 @@ import numpy as np
 import pytest
 import math
 
-from sklearn.model_selection import KFold
 from sklearn.base import clone
 
 from sklearn.linear_model import LogisticRegression, LinearRegression
@@ -10,14 +9,15 @@ from sklearn.ensemble import RandomForestClassifier, RandomForestRegressor
 
 import doubleml as dml
 
-from ._utils_iivm_manual import iivm_dml1, iivm_dml2, fit_nuisance_iivm, boot_iivm
+from ._utils import draw_smpls
+from ._utils_iivm_manual import fit_iivm, boot_iivm
 
 
 @pytest.fixture(scope='module',
-                params=[[LogisticRegression(solver='lbfgs', max_iter=250),
-                         LinearRegression()],
-                        [RandomForestClassifier(max_depth=2, n_estimators=10),
-                         RandomForestRegressor(max_depth=2, n_estimators=10)]])
+                params=[[LinearRegression(),
+                         LogisticRegression(solver='lbfgs', max_iter=250)],
+                        [RandomForestRegressor(max_depth=2, n_estimators=10),
+                         RandomForestClassifier(max_depth=2, n_estimators=10)]])
 def learner(request):
     return request.param
 
@@ -51,9 +51,9 @@ def dml_iivm_fixture(generate_data_iivm, learner, score, dml_procedure, trimming
     x_cols = data.columns[data.columns.str.startswith('X')].tolist()
 
     # Set machine learning methods for m & g
-    ml_g = clone(learner[1])
-    ml_m = clone(learner[0])
-    ml_r = clone(learner[0])
+    ml_g = clone(learner[0])
+    ml_m = clone(learner[1])
+    ml_r = clone(learner[1])
 
     np.random.seed(3141)
     obj_dml_data = dml.DoubleMLData(data, 'y', ['d'], x_cols, 'z')
@@ -70,39 +70,25 @@ def dml_iivm_fixture(generate_data_iivm, learner, score, dml_procedure, trimming
     x = data.loc[:, x_cols].values
     d = data['d'].values
     z = data['z'].values
-    resampling = KFold(n_splits=n_folds,
-                       shuffle=True)
-    smpls = [(train, test) for train, test in resampling.split(x)]
+    n_obs = len(y)
+    all_smpls = draw_smpls(n_obs, n_folds)
 
-    g_hat0, g_hat1, m_hat, r_hat0, r_hat1 = fit_nuisance_iivm(y, x, d, z,
-                                                              clone(learner[0]), clone(learner[1]), clone(learner[0]), smpls,
-                                                              trimming_threshold=trimming_threshold)
-
-    if dml_procedure == 'dml1':
-        res_manual, se_manual = iivm_dml1(y, x, d, z,
-                                          g_hat0, g_hat1, m_hat, r_hat0, r_hat1,
-                                          smpls, score)
-    else:
-        assert dml_procedure == 'dml2'
-        res_manual, se_manual = iivm_dml2(y, x, d, z,
-                                          g_hat0, g_hat1, m_hat, r_hat0, r_hat1,
-                                          smpls, score)
+    res_manual = fit_iivm(y, x, d, z,
+                          clone(learner[0]), clone(learner[1]), clone(learner[1]),
+                          all_smpls, dml_procedure, score, trimming_threshold=trimming_threshold)
 
     res_dict = {'coef': dml_iivm_obj.coef,
-                'coef_manual': res_manual,
+                'coef_manual': res_manual['theta'],
                 'se': dml_iivm_obj.se,
-                'se_manual': se_manual,
+                'se_manual': res_manual['se'],
                 'boot_methods': boot_methods}
 
     for bootstrap in boot_methods:
         np.random.seed(3141)
-        boot_theta, boot_t_stat = boot_iivm(res_manual,
-                                            y, d, z,
-                                            g_hat0, g_hat1, m_hat, r_hat0, r_hat1,
-                                            smpls, score,
-                                            se_manual,
-                                            bootstrap, n_rep_boot,
-                                            dml_procedure)
+        boot_theta, boot_t_stat = boot_iivm(y, d, z, res_manual['thetas'], res_manual['ses'],
+                                            res_manual['all_g_hat0'], res_manual['all_g_hat1'],
+                                            res_manual['all_m_hat'], res_manual['all_r_hat0'], res_manual['all_r_hat1'],
+                                            all_smpls, score, bootstrap, n_rep_boot)
 
         np.random.seed(3141)
         dml_iivm_obj.bootstrap(method=bootstrap, n_rep_boot=n_rep_boot)
