@@ -2,15 +2,14 @@ import numpy as np
 import pytest
 import math
 
-from sklearn.model_selection import KFold
 from sklearn.base import clone
 
 from sklearn.linear_model import Lasso
 
 import doubleml as dml
 
-from ._utils_pliv_partial_xz_manual import pliv_partial_xz_dml1, pliv_partial_xz_dml2, \
-    fit_nuisance_pliv_partial_xz, boot_pliv_partial_xz
+from ._utils import draw_smpls
+from ._utils_pliv_partial_xz_manual import fit_pliv_partial_xz, boot_pliv_partial_xz
 
 
 @pytest.fixture(scope='module',
@@ -58,42 +57,25 @@ def dml_pliv_partial_xz_fixture(generate_data_pliv_partialXZ, learner, score, dm
     x = obj_dml_data.x
     d = obj_dml_data.d
     z = obj_dml_data.z
-    resampling = KFold(n_splits=n_folds,
-                       shuffle=True)
-    smpls = [(train, test) for train, test in resampling.split(x)]
+    n_obs = len(y)
+    all_smpls = draw_smpls(n_obs, n_folds)
 
-    g_hat, m_hat, r_hat = fit_nuisance_pliv_partial_xz(y, x, d, z,
-                                                       clone(learner), clone(learner), clone(learner),
-                                                       smpls)
-
-    if dml_procedure == 'dml1':
-        res_manual, se_manual = pliv_partial_xz_dml1(y, x, d,
-                                                     z,
-                                                     g_hat, m_hat, r_hat,
-                                                     smpls, score)
-    else:
-        assert dml_procedure == 'dml2'
-        res_manual, se_manual = pliv_partial_xz_dml2(y, x, d,
-                                                     z,
-                                                     g_hat, m_hat, r_hat,
-                                                     smpls, score)
+    res_manual = fit_pliv_partial_xz(y, x, d, z,
+                                     clone(learner), clone(learner), clone(learner),
+                                     all_smpls, dml_procedure, score)
 
     res_dict = {'coef': dml_pliv_obj.coef,
-                'coef_manual': res_manual,
+                'coef_manual': res_manual['theta'],
                 'se': dml_pliv_obj.se,
-                'se_manual': se_manual,
+                'se_manual': res_manual['se'],
                 'boot_methods': boot_methods}
 
     for bootstrap in boot_methods:
         np.random.seed(3141)
-        boot_theta, boot_t_stat = boot_pliv_partial_xz(res_manual,
-                                                       y, d,
-                                                       z,
-                                                       g_hat, m_hat, r_hat,
-                                                       smpls, score,
-                                                       se_manual,
-                                                       bootstrap, n_rep_boot,
-                                                       dml_procedure)
+        boot_theta, boot_t_stat = boot_pliv_partial_xz(y, d, z, res_manual['thetas'], res_manual['ses'],
+                                                       res_manual['all_g_hat'], res_manual['all_m_hat'],
+                                                       res_manual['all_r_hat'],
+                                                       all_smpls, score, bootstrap, n_rep_boot)
 
         np.random.seed(3141)
         dml_pliv_obj.bootstrap(method=bootstrap, n_rep_boot=n_rep_boot)
