@@ -9,7 +9,7 @@ if (on_cran) {
   setting_irm = list(theta = 0.5, n = 5000, p = 20)
 }
 
-setting_pliv_partial = list(theta=1.0, n = 500)
+setting_pliv_partial = list(theta = 1.0, n = 500)
 
 set.seed(1282)
 df = dgp1_plr(
@@ -18,10 +18,11 @@ df = dgp1_plr(
   setting$p)
 Xnames = names(df)[names(df) %in% c("y", "d", "z") == FALSE]
 dml_data = double_ml_data_from_data_frame(df,
-                                          y_col = "y",
-                                          d_cols = "d", x_cols = Xnames)
-data_plr = list(df = df,
-                dml_data = dml_data)
+  y_col = "y",
+  d_cols = "d", x_cols = Xnames)
+data_plr = list(
+  df = df,
+  dml_data = dml_data)
 
 set.seed(1282)
 df = dgp1_iv(
@@ -30,10 +31,11 @@ df = dgp1_iv(
   setting$p)
 Xnames = names(df)[names(df) %in% c("y", "d", "z") == FALSE] # note that Xnames includes z2
 dml_data = double_ml_data_from_data_frame(df,
-                                          y_col = "y",
-                                          d_cols = "d", x_cols = Xnames, z_cols = "z")
-data_pliv = list(df = df,
-                 dml_data = dml_data)
+  y_col = "y",
+  d_cols = "d", x_cols = Xnames, z_cols = "z")
+data_pliv = list(
+  df = df,
+  dml_data = dml_data)
 
 set.seed(1282)
 df = dgp1_irm(
@@ -42,10 +44,11 @@ df = dgp1_irm(
   setting_irm$p)
 Xnames = names(df)[names(df) %in% c("y", "d", "z") == FALSE]
 dml_data = double_ml_data_from_data_frame(df,
-                                          y_col = "y",
-                                          d_cols = "d", x_cols = Xnames)
-data_irm = list(df = df,
-                dml_data = dml_data)
+  y_col = "y",
+  d_cols = "d", x_cols = Xnames)
+data_irm = list(
+  df = df,
+  dml_data = dml_data)
 
 set.seed(1282)
 df = dgp1_irmiv(
@@ -54,10 +57,11 @@ df = dgp1_irmiv(
   setting$p)
 Xnames = names(df)[names(df) %in% c("y", "d", "z") == FALSE]
 dml_data = double_ml_data_from_data_frame(df,
-                                          y_col = "y",
-                                          d_cols = "d", x_cols = Xnames, z_col = "z")
-data_iivm = list(df = df,
-                 dml_data = dml_data)
+  y_col = "y",
+  d_cols = "d", x_cols = Xnames, z_col = "z")
+data_iivm = list(
+  df = df,
+  dml_data = dml_data)
 
 set.seed(1282)
 data_plr_multi = dgp1_toeplitz(
@@ -73,10 +77,11 @@ df = make_pliv_CHS2015(
   return_type = "data.frame")
 Xnames = names(df)[names(df) %in% c("y", "d", paste0("Z", 1:dim_z)) == FALSE]
 dml_data = double_ml_data_from_data_frame(df,
-                                          y_col = "y",
-                                          d_cols = "d", x_cols = Xnames, z_cols = paste0("Z", 1:dim_z))
-data_pliv_partialXZ = list(df = df,
-                           dml_data = dml_data)
+  y_col = "y",
+  d_cols = "d", x_cols = Xnames, z_cols = paste0("Z", 1:dim_z))
+data_pliv_partialXZ = list(
+  df = df,
+  dml_data = dml_data)
 
 set.seed(1282)
 dim_z = 5
@@ -87,10 +92,11 @@ df = make_pliv_CHS2015(
   return_type = "data.frame")
 Xnames = names(df)[names(df) %in% c("y", "d", paste0("Z", 1:dim_z)) == FALSE]
 dml_data = double_ml_data_from_data_frame(df,
-                                          y_col = "y",
-                                          d_cols = "d", x_cols = Xnames, z_cols = paste0("Z", 1:dim_z))
-data_pliv_partialX = list(df = df,
-                          dml_data = dml_data)
+  y_col = "y",
+  d_cols = "d", x_cols = Xnames, z_cols = paste0("Z", 1:dim_z))
+data_pliv_partialX = list(
+  df = df,
+  dml_data = dml_data)
 
 set.seed(1282)
 dim_z = 150
@@ -100,7 +106,8 @@ df = make_data_pliv_partialZ(
   dim_x = 5)
 Xnames = names(df)[names(df) %in% c("y", "d", paste0("Z", 1:dim_z)) == FALSE]
 dml_data = double_ml_data_from_data_frame(df,
-                                          y_col = "y",
-                                          d_cols = "d", x_cols = Xnames, z_cols = paste0("Z", 1:dim_z))
-data_pliv_partialZ = list(df = df,
-                          dml_data = dml_data)
+  y_col = "y",
+  d_cols = "d", x_cols = Xnames, z_cols = paste0("Z", 1:dim_z))
+data_pliv_partialZ = list(
+  df = df,
+  dml_data = dml_data)
