@@ -33,7 +33,7 @@ if (on_cran) {
 }
 
 
-test_cases["test_name"] = apply(test_cases, 1, paste, collapse = "_")
+test_cases[".test_name"] = apply(test_cases, 1, paste, collapse = "_")
 
 # skip('Skip tests for PLR tuning')
 patrick::with_parameters_test_that("Unit tests for tuning of PLR:",
