@@ -17,7 +17,7 @@ score_fct = function(y, d, g_hat, m_hat, smpls) {
 on_cran = !identical(Sys.getenv("NOT_CRAN"), "true")
 if (on_cran) {
   test_cases = expand.grid(
-    learner = "regr.glmnet",
+    learner = "regr.lm",
     dml_procedure = "dml1",
     n_folds = c(3),
     n_rep = c(2),
